@@ -1,10 +1,8 @@
 /**
- *  Copyright (c) 2015, Facebook, Inc.
- *  All rights reserved.
+ * Copyright (c) 2015-present, Facebook, Inc.
  *
- *  This source code is licensed under the BSD-style license found in the
- *  LICENSE file in the root directory of this source tree. An additional grant
- *  of patent rights can be found in the PATENTS file in the same directory.
+ * This source code is licensed under the MIT license found in the
+ * LICENSE file in the root directory of this source tree.
  */
 
 #include "GraphQLAstNode.h"
@@ -14,7 +12,7 @@ using facebook::graphql::ast::Node;
 
 void graphql_node_get_location(const struct GraphQLAstNode *node,
                                struct GraphQLAstLocation *location) {
-  const Node *realNode = (Node *)node;
+  const auto *realNode = reinterpret_cast<const Node *>(node);
   const auto &loc = realNode->getLocation();
   location->beginLine = loc.begin.line;
   location->beginColumn = loc.begin.column;
@@ -23,5 +21,5 @@ void graphql_node_get_location(const struct GraphQLAstNode *node,
 }
 
 void graphql_node_free(struct GraphQLAstNode *node) {
-  delete (Node *)node;
+  delete reinterpret_cast<Node *>(node);
 }
